package SmallRNA::DB::Dbxref;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Dbxref

=head1 DESCRIPTION

A unique, global, public, stable identifier. Not necessarily an external reference - can reference data items inside the particular chado instance being used. Typically a row in a table can be uniquely identified with a primary identifier (called dbxref_id); a table may also have secondary identifiers (in a linking table <T>_dbxref). A dbxref is generally written as <DB>:<ACCESSION> or as <DB>:<ACCESSION>:<VERSION>.

=cut

__PACKAGE__->table("dbxref");

=head1 ACCESSORS

=head2 dbxref_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'dbxref_dbxref_id_seq'

=head2 db_id

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 accession

  data_type: 'varchar'
  is_nullable: 0
  size: 255

The local part of the identifier. Guaranteed by the db authority to be unique for that db.

=head2 version

  data_type: 'varchar'
  default_value: (empty string)
  is_nullable: 0
  size: 255

=head2 description

  data_type: 'text'
  is_nullable: 1

=cut

__PACKAGE__->add_columns(
  "dbxref_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "dbxref_dbxref_id_seq",
  },
  "db_id",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "accession",
  { data_type => "varchar", is_nullable => 0, size => 255 },
  "version",
  { data_type => "varchar", default_value => "", is_nullable => 0, size => 255 },
  "description",
  { data_type => "text", is_nullable => 1 },
);
__PACKAGE__->set_primary_key("dbxref_id");
__PACKAGE__->add_unique_constraint("dbxref_c1", ["db_id", "accession", "version"]);

=head1 RELATIONS

=head2 biosample_dbxrefs

Type: has_many

Related object: L<SmallRNA::DB::BiosampleDbxref>

=cut

__PACKAGE__->has_many(
  "biosample_dbxrefs",
  "SmallRNA::DB::BiosampleDbxref",
  { "foreign.dbxref_id" => "self.dbxref_id" },
  {},
);

=head2 cvterm_dbxrefs

Type: has_many

Related object: L<SmallRNA::DB::CvtermDbxref>

=cut

__PACKAGE__->has_many(
  "cvterm_dbxrefs",
  "SmallRNA::DB::CvtermDbxref",
  { "foreign.dbxref_id" => "self.dbxref_id" },
  {},
);

=head2 db

Type: belongs_to

Related object: L<SmallRNA::DB::Db>

=cut

__PACKAGE__->belongs_to("db", "SmallRNA::DB::Db", { db_id => "db_id" });

=head2 organism_dbxrefs

Type: has_many

Related object: L<SmallRNA::DB::OrganismDbxref>

=cut

__PACKAGE__->has_many(
  "organism_dbxrefs",
  "SmallRNA::DB::OrganismDbxref",
  { "foreign.dbxref_id" => "self.dbxref_id" },
  {},
);

=head2 pub_dbxrefs

Type: has_many

Related object: L<SmallRNA::DB::PubDbxref>

=cut

__PACKAGE__->has_many(
  "pub_dbxrefs",
  "SmallRNA::DB::PubDbxref",
  { "foreign.dbxref_id" => "self.dbxref_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07000 @ 2011-06-01 01:11:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:n4YRjBFBE0OcFH0xtMX+dg

__PACKAGE__->many_to_many(extra_cvterms => 'cvterm_dbxrefs', 'cvterm');

# You can replace this text with custom content, and it will be preserved on regeneration
1;
