package SmallRNA::DB::Library;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Library

=cut

__PACKAGE__->table("library");

=head1 ACCESSORS

=head2 library_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'library_library_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 identifier

  data_type: 'text'
  is_nullable: 0

=head2 sequencing_centre_identifier

  data_type: 'text'
  is_nullable: 1

=head2 description

  data_type: 'text'
  is_nullable: 1

=head2 library_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 biosample

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 sequencing_sample

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 adaptor

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 barcode

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=cut

__PACKAGE__->add_columns(
  "library_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "library_library_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "identifier",
  { data_type => "text", is_nullable => 0 },
  "sequencing_centre_identifier",
  { data_type => "text", is_nullable => 1 },
  "description",
  { data_type => "text", is_nullable => 1 },
  "library_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "biosample",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "sequencing_sample",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "adaptor",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "barcode",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
);
__PACKAGE__->set_primary_key("library_id");
__PACKAGE__->add_unique_constraint("library_identifier_key", ["identifier"]);
__PACKAGE__->add_unique_constraint(
  "library_sequencing_centre_identifier_key",
  ["sequencing_centre_identifier"],
);

=head1 RELATIONS

=head2 biosample

Type: belongs_to

Related object: L<SmallRNA::DB::Biosample>

=cut

__PACKAGE__->belongs_to(
  "biosample",
  "SmallRNA::DB::Biosample",
  { biosample_id => "biosample" },
);

=head2 sequencing_sample

Type: belongs_to

Related object: L<SmallRNA::DB::SequencingSample>

=cut

__PACKAGE__->belongs_to(
  "sequencing_sample",
  "SmallRNA::DB::SequencingSample",
  { sequencing_sample_id => "sequencing_sample" },
);

=head2 library_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "library_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "library_type" },
);

=head2 barcode

Type: belongs_to

Related object: L<SmallRNA::DB::Barcode>

=cut

__PACKAGE__->belongs_to(
  "barcode",
  "SmallRNA::DB::Barcode",
  { barcode_id => "barcode" },
);

=head2 adaptor

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to("adaptor", "SmallRNA::DB::Cvterm", { cvterm_id => "adaptor" });


# Created by DBIx::Class::Schema::Loader v0.07002 @ 2011-07-02 23:35:17
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:6zIhZRVqcMAd/h71KejJ0A


# You can replace this text with custom content, and it will be preserved on regeneration
1;
