package SmallRNA::DB::Organism;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Organism

=head1 DESCRIPTION

The organismal taxonomic
classification. Note that phylogenies are represented using the
phylogeny module, and taxonomies can be represented using the cvterm
module or the phylogeny module.

=cut

__PACKAGE__->table("organism");

=head1 ACCESSORS

=head2 organism_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'organism_organism_id_seq'

=head2 abbreviation

  data_type: 'varchar'
  is_nullable: 1
  size: 255

=head2 genus

  data_type: 'varchar'
  is_nullable: 0
  size: 255

=head2 species

  data_type: 'varchar'
  is_nullable: 0
  size: 255

A type of organism is always
uniquely identified by genus and species. When mapping from the NCBI
taxonomy names.dmp file, this column must be used where it
is present, as the common_name column is not always unique (e.g. environmental
samples). If a particular strain or subspecies is to be represented,
this is appended onto the species name. Follows standard NCBI taxonomy
pattern.

=head2 common_name

  data_type: 'varchar'
  is_nullable: 1
  size: 255

=head2 comment

  data_type: 'text'
  is_nullable: 1

=cut

__PACKAGE__->add_columns(
  "organism_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "organism_organism_id_seq",
  },
  "abbreviation",
  { data_type => "varchar", is_nullable => 1, size => 255 },
  "genus",
  { data_type => "varchar", is_nullable => 0, size => 255 },
  "species",
  { data_type => "varchar", is_nullable => 0, size => 255 },
  "common_name",
  { data_type => "varchar", is_nullable => 1, size => 255 },
  "comment",
  { data_type => "text", is_nullable => 1 },
);
__PACKAGE__->set_primary_key("organism_id");
__PACKAGE__->add_unique_constraint("organism_c1", ["genus", "species"]);

=head1 RELATIONS

=head2 ecotypes

Type: has_many

Related object: L<SmallRNA::DB::Ecotype>

=cut

__PACKAGE__->has_many(
  "ecotypes",
  "SmallRNA::DB::Ecotype",
  { "foreign.organism" => "self.organism_id" },
  {},
);

=head2 organism_dbxrefs

Type: has_many

Related object: L<SmallRNA::DB::OrganismDbxref>

=cut

__PACKAGE__->has_many(
  "organism_dbxrefs",
  "SmallRNA::DB::OrganismDbxref",
  { "foreign.organism_id" => "self.organism_id" },
  {},
);

=head2 tissues

Type: has_many

Related object: L<SmallRNA::DB::Tissue>

=cut

__PACKAGE__->has_many(
  "tissues",
  "SmallRNA::DB::Tissue",
  { "foreign.organism" => "self.organism_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07000 @ 2011-06-01 01:11:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:GbzYOE1s+A0ultkVGxBwtA

# the genus and species, used when displaying organisms
sub full_name {
  my $self = shift;

  return $self->genus() . ' ' . $self->species();
}

# You can replace this text with custom content, and it will be preserved on regeneration
1;
