package SmallRNA::DB::Pipeprocess;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Pipeprocess

=cut

__PACKAGE__->table("pipeprocess");

=head1 ACCESSORS

=head2 pipeprocess_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'pipeprocess_pipeprocess_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 description

  data_type: 'text'
  is_nullable: 0

=head2 process_conf

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 status

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 job_identifier

  data_type: 'text'
  is_nullable: 1

=head2 time_queued

  data_type: 'timestamp'
  is_nullable: 1

=head2 time_started

  data_type: 'timestamp'
  is_nullable: 1

=head2 time_finished

  data_type: 'timestamp'
  is_nullable: 1

=cut

__PACKAGE__->add_columns(
  "pipeprocess_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "pipeprocess_pipeprocess_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "description",
  { data_type => "text", is_nullable => 0 },
  "process_conf",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "status",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "job_identifier",
  { data_type => "text", is_nullable => 1 },
  "time_queued",
  { data_type => "timestamp", is_nullable => 1 },
  "time_started",
  { data_type => "timestamp", is_nullable => 1 },
  "time_finished",
  { data_type => "timestamp", is_nullable => 1 },
);
__PACKAGE__->set_primary_key("pipeprocess_id");

=head1 RELATIONS

=head2 pipedatas

Type: has_many

Related object: L<SmallRNA::DB::Pipedata>

=cut

__PACKAGE__->has_many(
  "pipedatas",
  "SmallRNA::DB::Pipedata",
  { "foreign.generating_pipeprocess" => "self.pipeprocess_id" },
  {},
);

=head2 status

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to("status", "SmallRNA::DB::Cvterm", { cvterm_id => "status" });

=head2 process_conf

Type: belongs_to

Related object: L<SmallRNA::DB::ProcessConf>

=cut

__PACKAGE__->belongs_to(
  "process_conf",
  "SmallRNA::DB::ProcessConf",
  { process_conf_id => "process_conf" },
);

=head2 pipeprocess_in_pipedatas

Type: has_many

Related object: L<SmallRNA::DB::PipeprocessInPipedata>

=cut

__PACKAGE__->has_many(
  "pipeprocess_in_pipedatas",
  "SmallRNA::DB::PipeprocessInPipedata",
  { "foreign.pipeprocess" => "self.pipeprocess_id" },
  {},
);

=head2 pipeprocess_pubs

Type: has_many

Related object: L<SmallRNA::DB::PipeprocessPub>

=cut

__PACKAGE__->has_many(
  "pipeprocess_pubs",
  "SmallRNA::DB::PipeprocessPub",
  { "foreign.pipeprocess_id" => "self.pipeprocess_id" },
  {},
);

=head2 sequencing_runs

Type: has_many

Related object: L<SmallRNA::DB::SequencingRun>

=cut

__PACKAGE__->has_many(
  "sequencing_runs",
  "SmallRNA::DB::SequencingRun",
  { "foreign.initial_pipeprocess" => "self.pipeprocess_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07000 @ 2011-06-01 01:11:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:uIKYw6FbLJ7gWFaMzI+gvA

__PACKAGE__->many_to_many(input_pipedatas => 'pipeprocess_in_pipedatas',
                          'pipedata' );
__PACKAGE__->many_to_many(pubs => 'pipeprocess_pub', 'pub');

sub _delete_pipedata
{
  my $pipedata = shift;

  for my $pipeprocess ($pipedata->next_pipeprocesses()) {
    $pipeprocess->delete();
  }
}

=head2 delete

 Function: recursively delete pipeprocesses that depend on this process, then
           delete this process from the storage
 Args    : none

=cut
sub delete
{
  my $self = shift;

  for my $pipedata ($self->pipedatas()) {
    _delete_pipedata($pipedata)
  }

  $self->SUPER::delete();
}

1;
