#!/usr/bin/perl -w

eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
    if 0; # not running under some shell

# Main work process called through Condor or Torque
#
# The id of the Pipeprocess for this worker to run is passed in the
# PIPEPROCESS_ID environment variable
#
# The ProcessConf for the Pipeprocess is used to decide which
# SmallRNA::RunableI to run.  The Pipeprocess is passed to the run() method
# of the SmallRNA::RunableI.

# Find the pipeprocess with ID from the environment, update start time and
# status, run the process then update finished time and status

use strict;

BEGIN 
{
  push @INC, '/home/rn202/Documents/vbshare/ADDAPTS_0.7/pipeline/lib'; 
};

use DateTime;
use Carp;
use POSIX qw(nice);
use BSD::Resource qw(RLIMIT_VMEM setrlimit);

use SmallRNA::Config;
use SmallRNA::DB;
use SmallRNA::DBLayer::Loader;
use SmallRNA::PipeWork;

if (!exists $ENV{PIPEPROCESS_ID}) {
  die "no PIPEPROCESS_ID environment variable\n";
}

my $pipeprocess_id = $ENV{PIPEPROCESS_ID};

if (!exists $ENV{CONFIG_FILE_PATH}) {
  die "no CONFIG_FILE_PATH environment variable\n";
}

my $config_file_path = $ENV{CONFIG_FILE_PATH};

if (!-f $config_file_path) {
  $config_file_path =~ s:^/export/:/:;
}

my $config = SmallRNA::Config->new($config_file_path);
my $schema = SmallRNA::DB->new($config);

my $started_status = $schema->find_with_type('Cvterm', name => 'started');

my $pipeprocess = $schema->resultset('Pipeprocess')->find($pipeprocess_id);

if (!defined $pipeprocess) {
  croak "error: can't find pipeprocess with id: $pipeprocess_id\n";
}

if (!$ENV{SMALLRNA_PIPELINE_TEST}) {
  # make the process nice and prevent excess memory use
  POSIX::nice(19);
  setrlimit(RLIMIT_VMEM, 32_000_000_000, 32_000_000_000);
}

my $current_status;

$schema->txn_do(sub {
                  my $time_started = $pipeprocess->time_started();
                  $current_status = $pipeprocess->status()->name();

                  if (defined $time_started) {
                    warn "error: process $pipeprocess_id (status: $current_status) already started at: $time_started\n";
                  }

                  if ($current_status eq 'queued') {
                    $pipeprocess->time_started(DateTime->now());
                    $pipeprocess->status($started_status);
                    $current_status = 'started';
                    $pipeprocess->update();
                  }
                });

if ($current_status ne 'started') {
  $schema->storage()->disconnect();
  # already started - perhaps two pipeserv.pl processes are running?
  die 'pipeprocess ', $pipeprocess_id, " already started - exiting\n";
}

my $status;
my $message;

eval {
  $schema->txn_do(sub {
                    ($status, $message) =
                      SmallRNA::PipeWork::run_process(schema => $schema,
                                                      config => $config,
                                                      pipeprocess => $pipeprocess);
                    if ($status eq 'failed') 
                    {
                      warn "$message\n";
                    }
                    
                    my $status_cvterm = $schema->find_with_type('Cvterm', name => $status);
                    if ($status eq 'finished') 
                    {
                      $pipeprocess->time_finished(DateTime->now());
                    }

                    $pipeprocess->status($status_cvterm);
                    $pipeprocess->update();
                  });
};

if ($@) {
  $schema->txn_do(sub {
                    my $failed_status = $schema->find_with_type('Cvterm', name => 'failed');
                    $pipeprocess->status($failed_status);
                    $pipeprocess->update();
                  });
  warn "run_process() failed for pipeprocess $pipeprocess_id: $@\n";
}

$schema->storage()->disconnect();
