package SmallRNA::DB::Barcode;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Barcode

=cut

__PACKAGE__->table("barcode");

=head1 ACCESSORS

=head2 barcode_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'barcode_barcode_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 identifier

  data_type: 'text'
  is_nullable: 0

=head2 barcode_set

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 code

  data_type: 'text'
  is_nullable: 0

=cut

__PACKAGE__->add_columns(
  "barcode_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "barcode_barcode_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "identifier",
  { data_type => "text", is_nullable => 0 },
  "barcode_set",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "code",
  { data_type => "text", is_nullable => 0 },
);
__PACKAGE__->set_primary_key("barcode_id");
__PACKAGE__->add_unique_constraint("barcode_code_constraint", ["code", "barcode_set"]);
__PACKAGE__->add_unique_constraint(
  "barcode_identifier_constraint",
  ["identifier", "barcode_set"],
);

=head1 RELATIONS

=head2 barcode_set

Type: belongs_to

Related object: L<SmallRNA::DB::BarcodeSet>

=cut

__PACKAGE__->belongs_to(
  "barcode_set",
  "SmallRNA::DB::BarcodeSet",
  { barcode_set_id => "barcode_set" },
);

=head2 libraries

Type: has_many

Related object: L<SmallRNA::DB::Library>

=cut

__PACKAGE__->has_many(
  "libraries",
  "SmallRNA::DB::Library",
  { "foreign.barcode" => "self.barcode_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07000 @ 2011-06-01 01:11:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:/AmlR6X+41AxEaeObi0xTQ

sub long_identifier
{
  my $self = shift;

  my $barcode_set_name = $self->barcode_set()->name();
  my $barcode_identifier = $self->identifier();
  my $barcode_code = $self->code();

  return "$barcode_identifier ($barcode_code) from $barcode_set_name";
}


# You can replace this text with custom content, and it will be preserved on regeneration
1;
