package SmallRNA::DB::Biosample;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Biosample

=cut

__PACKAGE__->table("biosample");

=head1 ACCESSORS

=head2 biosample_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'biosample_biosample_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 name

  data_type: 'text'
  is_nullable: 0

=head2 biosample_creator

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 genotype

  data_type: 'text'
  is_nullable: 1

=head2 description

  data_type: 'text'
  is_nullable: 0

=head2 protocol

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 biosample_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 molecule_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 treatment_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 fractionation_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 processing_requirement

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 tissue

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=cut

__PACKAGE__->add_columns(
  "biosample_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "biosample_biosample_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "name",
  { data_type => "text", is_nullable => 0 },
  "biosample_creator",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "genotype",
  { data_type => "text", is_nullable => 1 },
  "description",
  { data_type => "text", is_nullable => 0 },
  "protocol",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "biosample_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "molecule_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "treatment_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "fractionation_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "processing_requirement",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "tissue",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
);
__PACKAGE__->set_primary_key("biosample_id");
__PACKAGE__->add_unique_constraint("biosample_name_key", ["name"]);

=head1 RELATIONS

=head2 processing_requirement

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "processing_requirement",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "processing_requirement" },
);

=head2 tissue

Type: belongs_to

Related object: L<SmallRNA::DB::Tissue>

=cut

__PACKAGE__->belongs_to("tissue", "SmallRNA::DB::Tissue", { tissue_id => "tissue" });

=head2 protocol

Type: belongs_to

Related object: L<SmallRNA::DB::Protocol>

=cut

__PACKAGE__->belongs_to(
  "protocol",
  "SmallRNA::DB::Protocol",
  { protocol_id => "protocol" },
);

=head2 molecule_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "molecule_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "molecule_type" },
);

=head2 fractionation_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "fractionation_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "fractionation_type" },
);

=head2 biosample_creator

Type: belongs_to

Related object: L<SmallRNA::DB::Person>

=cut

__PACKAGE__->belongs_to(
  "biosample_creator",
  "SmallRNA::DB::Person",
  { person_id => "biosample_creator" },
);

=head2 treatment_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "treatment_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "treatment_type" },
);

=head2 biosample_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "biosample_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "biosample_type" },
);

=head2 biosample_dbxrefs

Type: has_many

Related object: L<SmallRNA::DB::BiosampleDbxref>

=cut

__PACKAGE__->has_many(
  "biosample_dbxrefs",
  "SmallRNA::DB::BiosampleDbxref",
  { "foreign.biosample_id" => "self.biosample_id" },
  {},
);

=head2 biosample_ecotypes

Type: has_many

Related object: L<SmallRNA::DB::BiosampleEcotype>

=cut

__PACKAGE__->has_many(
  "biosample_ecotypes",
  "SmallRNA::DB::BiosampleEcotype",
  { "foreign.biosample" => "self.biosample_id" },
  {},
);

=head2 biosample_pipedatas

Type: has_many

Related object: L<SmallRNA::DB::BiosamplePipedata>

=cut

__PACKAGE__->has_many(
  "biosample_pipedatas",
  "SmallRNA::DB::BiosamplePipedata",
  { "foreign.biosample" => "self.biosample_id" },
  {},
);

=head2 biosample_pipeprojects

Type: has_many

Related object: L<SmallRNA::DB::BiosamplePipeproject>

=cut

__PACKAGE__->has_many(
  "biosample_pipeprojects",
  "SmallRNA::DB::BiosamplePipeproject",
  { "foreign.biosample" => "self.biosample_id" },
  {},
);

=head2 libraries

Type: has_many

Related object: L<SmallRNA::DB::Library>

=cut

__PACKAGE__->has_many(
  "libraries",
  "SmallRNA::DB::Library",
  { "foreign.biosample" => "self.biosample_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07000 @ 2011-06-01 01:11:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:vvomIWYgmgYjuoyZ1JJaxw

__PACKAGE__->many_to_many('pipedatas' => 'biosample_pipedatas', 'pipedata');
__PACKAGE__->many_to_many('ecotypes' => 'biosample_ecotypes', 'ecotype');
__PACKAGE__->many_to_many('pipeprojects' => 'biosample_pipeprojects', 'pipeproject');

my %_fasta_counts_cache = ();

my $_cache_time = undef;
my $MAX_CACHE_AGE = 10 * 60;  # 10 minutes

sub _populate_fasta_counts_cache
{
  my $schema = shift;

  my $query = <<"END";
SELECT biosample.name AS biosample_name,
       pipedata_content_type.name AS pipedata_content_type_name,
       property_type_cvterm.name AS property_type_name,
       pipedata_property.value AS prop_value
  FROM biosample
  LEFT JOIN biosample_pipedata on biosample_pipedata.biosample = biosample.biosample_id
  LEFT JOIN pipedata on biosample_pipedata.pipedata = pipedata.pipedata_id
  LEFT JOIN pipedata_property
               ON pipedata_property.pipedata = pipedata.pipedata_id
  LEFT JOIN cvterm pipedata_content_type
               ON pipedata_content_type.cvterm_id = pipedata.content_type
  LEFT JOIN cvterm property_type_cvterm
               ON property_type_cvterm.cvterm_id = pipedata_property.type
END

  my $start_time = time();

  my $dbh = $schema->storage()->dbh();
  my $sth = $dbh->prepare($query) || die $dbh->errstr;
  $sth->execute() || die $sth->errstr;

  while (my $r = $sth->fetchrow_hashref()) {
    my $biosample_name = $r->{biosample_name};
    my $pipedata_content_type_name = $r->{pipedata_content_type_name};
    my $property_type_name = $r->{property_type_name};
    my $prop_value = $r->{prop_value};

    if (defined $pipedata_content_type_name && defined $property_type_name) {
      $_fasta_counts_cache{$biosample_name}{$pipedata_content_type_name}{$property_type_name} = $prop_value;
    } else {
      if (!exists $_fasta_counts_cache{$biosample_name}) {
        # placeholder so that we know we've queried for this biosample before
        $_fasta_counts_cache{$biosample_name} = undef;
      }
    }
  }

  $_cache_time = time();
}

=head2 get_pipedata_property

 Function: Get a pipedata_property of a pipedata of a Biosample
 Args    : $biosample - the Biosample object
           $pipedata_content_type_name - the content type of the pipedata whose
              properties interest us
           $property_type_name - the property type to find
 Returns : the property value, or undef

=cut
sub get_pipedata_property
{
  my $biosample = shift;
  my $pipedata_content_type_name = shift;
  my $property_type_name = shift;

  my $biosample_name = $biosample->name();

  if (!exists $_fasta_counts_cache{$biosample_name} ||
      !defined $_cache_time ||
      (time() - $_cache_time > $MAX_CACHE_AGE)) {
    my $schema = $biosample->result_source->schema();
    _populate_fasta_counts_cache($schema);
  }

  return $_fasta_counts_cache{$biosample_name}{$pipedata_content_type_name}{$property_type_name};
}

1;
