package SmallRNA::DB::Cvterm;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Cvterm

=head1 DESCRIPTION

A term, class, universal or type within an
ontology or controlled vocabulary.  This table is also used for
relations and properties. cvterms constitute nodes in the graph
defined by the collection of cvterms and cvterm_relationships.

=cut

__PACKAGE__->table("cvterm");

=head1 ACCESSORS

=head2 cvterm_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'cvterm_cvterm_id_seq'

=head2 cv_id

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

The cv or ontology or namespace to which
this cvterm belongs.

=head2 name

  data_type: 'varchar'
  is_nullable: 0
  size: 1024

A concise human-readable name or
label for the cvterm. Uniquely identifies a cvterm within a cv.

=head2 definition

  data_type: 'text'
  is_nullable: 1

A human-readable text
definition.

=cut

__PACKAGE__->add_columns(
  "cvterm_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "cvterm_cvterm_id_seq",
  },
  "cv_id",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "name",
  { data_type => "varchar", is_nullable => 0, size => 1024 },
  "definition",
  { data_type => "text", is_nullable => 1 },
);
__PACKAGE__->set_primary_key("cvterm_id");

=head1 RELATIONS

=head2 barcode_sets

Type: has_many

Related object: L<SmallRNA::DB::BarcodeSet>

=cut

__PACKAGE__->has_many(
  "barcode_sets",
  "SmallRNA::DB::BarcodeSet",
  { "foreign.position_in_read" => "self.cvterm_id" },
  {},
);

=head2 biosample_processing_requirements

Type: has_many

Related object: L<SmallRNA::DB::Biosample>

=cut

__PACKAGE__->has_many(
  "biosample_processing_requirements",
  "SmallRNA::DB::Biosample",
  { "foreign.processing_requirement" => "self.cvterm_id" },
  {},
);

=head2 biosample_molecule_types

Type: has_many

Related object: L<SmallRNA::DB::Biosample>

=cut

__PACKAGE__->has_many(
  "biosample_molecule_types",
  "SmallRNA::DB::Biosample",
  { "foreign.molecule_type" => "self.cvterm_id" },
  {},
);

=head2 biosample_fractionation_types

Type: has_many

Related object: L<SmallRNA::DB::Biosample>

=cut

__PACKAGE__->has_many(
  "biosample_fractionation_types",
  "SmallRNA::DB::Biosample",
  { "foreign.fractionation_type" => "self.cvterm_id" },
  {},
);

=head2 biosample_treatment_types

Type: has_many

Related object: L<SmallRNA::DB::Biosample>

=cut

__PACKAGE__->has_many(
  "biosample_treatment_types",
  "SmallRNA::DB::Biosample",
  { "foreign.treatment_type" => "self.cvterm_id" },
  {},
);

=head2 biosample_biosample_types

Type: has_many

Related object: L<SmallRNA::DB::Biosample>

=cut

__PACKAGE__->has_many(
  "biosample_biosample_types",
  "SmallRNA::DB::Biosample",
  { "foreign.biosample_type" => "self.cvterm_id" },
  {},
);

=head2 cv

Type: belongs_to

Related object: L<SmallRNA::DB::Cv>

=cut

__PACKAGE__->belongs_to("cv", "SmallRNA::DB::Cv", { cv_id => "cv_id" });

=head2 cvterm_dbxrefs

Type: has_many

Related object: L<SmallRNA::DB::CvtermDbxref>

=cut

__PACKAGE__->has_many(
  "cvterm_dbxrefs",
  "SmallRNA::DB::CvtermDbxref",
  { "foreign.cvterm_id" => "self.cvterm_id" },
  {},
);

=head2 library_library_types

Type: has_many

Related object: L<SmallRNA::DB::Library>

=cut

__PACKAGE__->has_many(
  "library_library_types",
  "SmallRNA::DB::Library",
  { "foreign.library_type" => "self.cvterm_id" },
  {},
);

=head2 library_adaptors

Type: has_many

Related object: L<SmallRNA::DB::Library>

=cut

__PACKAGE__->has_many(
  "library_adaptors",
  "SmallRNA::DB::Library",
  { "foreign.adaptor" => "self.cvterm_id" },
  {},
);

=head2 people

Type: has_many

Related object: L<SmallRNA::DB::Person>

=cut

__PACKAGE__->has_many(
  "people",
  "SmallRNA::DB::Person",
  { "foreign.role" => "self.cvterm_id" },
  {},
);

=head2 pipedata_content_types

Type: has_many

Related object: L<SmallRNA::DB::Pipedata>

=cut

__PACKAGE__->has_many(
  "pipedata_content_types",
  "SmallRNA::DB::Pipedata",
  { "foreign.content_type" => "self.cvterm_id" },
  {},
);

=head2 pipedata_format_types

Type: has_many

Related object: L<SmallRNA::DB::Pipedata>

=cut

__PACKAGE__->has_many(
  "pipedata_format_types",
  "SmallRNA::DB::Pipedata",
  { "foreign.format_type" => "self.cvterm_id" },
  {},
);

=head2 pipedata_properties

Type: has_many

Related object: L<SmallRNA::DB::PipedataProperty>

=cut

__PACKAGE__->has_many(
  "pipedata_properties",
  "SmallRNA::DB::PipedataProperty",
  { "foreign.type" => "self.cvterm_id" },
  {},
);

=head2 pipeprocesses

Type: has_many

Related object: L<SmallRNA::DB::Pipeprocess>

=cut

__PACKAGE__->has_many(
  "pipeprocesses",
  "SmallRNA::DB::Pipeprocess",
  { "foreign.status" => "self.cvterm_id" },
  {},
);

=head2 process_confs

Type: has_many

Related object: L<SmallRNA::DB::ProcessConf>

=cut

__PACKAGE__->has_many(
  "process_confs",
  "SmallRNA::DB::ProcessConf",
  { "foreign.type" => "self.cvterm_id" },
  {},
);

=head2 process_conf_input_format_types

Type: has_many

Related object: L<SmallRNA::DB::ProcessConfInput>

=cut

__PACKAGE__->has_many(
  "process_conf_input_format_types",
  "SmallRNA::DB::ProcessConfInput",
  { "foreign.format_type" => "self.cvterm_id" },
  {},
);

=head2 process_conf_input_biosample_types

Type: has_many

Related object: L<SmallRNA::DB::ProcessConfInput>

=cut

__PACKAGE__->has_many(
  "process_conf_input_biosample_types",
  "SmallRNA::DB::ProcessConfInput",
  { "foreign.biosample_type" => "self.cvterm_id" },
  {},
);

=head2 process_conf_input_content_types

Type: has_many

Related object: L<SmallRNA::DB::ProcessConfInput>

=cut

__PACKAGE__->has_many(
  "process_conf_input_content_types",
  "SmallRNA::DB::ProcessConfInput",
  { "foreign.content_type" => "self.cvterm_id" },
  {},
);

=head2 pubs

Type: has_many

Related object: L<SmallRNA::DB::Pub>

=cut

__PACKAGE__->has_many(
  "pubs",
  "SmallRNA::DB::Pub",
  { "foreign.type_id" => "self.cvterm_id" },
  {},
);

=head2 sequencing_run_qualities

Type: has_many

Related object: L<SmallRNA::DB::SequencingRun>

=cut

__PACKAGE__->has_many(
  "sequencing_run_qualities",
  "SmallRNA::DB::SequencingRun",
  { "foreign.quality" => "self.cvterm_id" },
  {},
);

=head2 sequencing_run_sequencing_types

Type: has_many

Related object: L<SmallRNA::DB::SequencingRun>

=cut

__PACKAGE__->has_many(
  "sequencing_run_sequencing_types",
  "SmallRNA::DB::SequencingRun",
  { "foreign.sequencing_type" => "self.cvterm_id" },
  {},
);

=head2 sequencing_sample_end_types

Type: has_many

Related object: L<SmallRNA::DB::SequencingSample>

=cut

__PACKAGE__->has_many(
  "sequencing_sample_end_types",
  "SmallRNA::DB::SequencingSample",
  { "foreign.end_type" => "self.cvterm_id" },
  {},
);

=head2 sequencing_sample_device_types

Type: has_many

Related object: L<SmallRNA::DB::SequencingSample>

=cut

__PACKAGE__->has_many(
  "sequencing_sample_device_types",
  "SmallRNA::DB::SequencingSample",
  { "foreign.device_type" => "self.cvterm_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07002 @ 2011-07-02 23:35:17
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:Iumr8UXcG9qwp/nAWOXdYA

__PACKAGE__->many_to_many(dbxrefs => 'cvterm_dbxrefs', 'dbxref');


# You can replace this text with custom content, and it will be preserved on regeneration
1;
