package SmallRNA::DB::Ecotype;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Ecotype

=cut

__PACKAGE__->table("ecotype");

=head1 ACCESSORS

=head2 ecotype_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'ecotype_ecotype_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 organism

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 description

  data_type: 'text'
  is_nullable: 0

=cut

__PACKAGE__->add_columns(
  "ecotype_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "ecotype_ecotype_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "organism",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "description",
  { data_type => "text", is_nullable => 0 },
);
__PACKAGE__->set_primary_key("ecotype_id");

=head1 RELATIONS

=head2 biosample_ecotypes

Type: has_many

Related object: L<SmallRNA::DB::BiosampleEcotype>

=cut

__PACKAGE__->has_many(
  "biosample_ecotypes",
  "SmallRNA::DB::BiosampleEcotype",
  { "foreign.ecotype" => "self.ecotype_id" },
  {},
);

=head2 organism

Type: belongs_to

Related object: L<SmallRNA::DB::Organism>

=cut

__PACKAGE__->belongs_to(
  "organism",
  "SmallRNA::DB::Organism",
  { organism_id => "organism" },
);

=head2 process_conf_inputs

Type: has_many

Related object: L<SmallRNA::DB::ProcessConfInput>

=cut

__PACKAGE__->has_many(
  "process_conf_inputs",
  "SmallRNA::DB::ProcessConfInput",
  { "foreign.ecotype" => "self.ecotype_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07000 @ 2011-06-01 01:11:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:3cT6GZhuow6S1NAm8k4TSQ

# the description and the organism full name, used when displaying ecotypes
sub long_description
{
  my $self = shift;

  return $self->description() . ' ' . $self->organism()->full_name();
}

__PACKAGE__->many_to_many('biosamples' => 'biosample_ecotypes', 'biosample');

# You can replace this text with custom content, and it will be preserved on regeneration
1;
