package SmallRNA::DB::Organisation;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Organisation

=cut

__PACKAGE__->table("organisation");

=head1 ACCESSORS

=head2 organisation_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'organisation_organisation_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 name

  data_type: 'text'
  is_nullable: 0

=head2 description

  data_type: 'text'
  is_nullable: 1

=cut

__PACKAGE__->add_columns(
  "organisation_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "organisation_organisation_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "name",
  { data_type => "text", is_nullable => 0 },
  "description",
  { data_type => "text", is_nullable => 1 },
);
__PACKAGE__->set_primary_key("organisation_id");

=head1 RELATIONS

=head2 people

Type: has_many

Related object: L<SmallRNA::DB::Person>

=cut

__PACKAGE__->has_many(
  "people",
  "SmallRNA::DB::Person",
  { "foreign.organisation" => "self.organisation_id" },
  {},
);

=head2 pipeprojects

Type: has_many

Related object: L<SmallRNA::DB::Pipeproject>

=cut

__PACKAGE__->has_many(
  "pipeprojects",
  "SmallRNA::DB::Pipeproject",
  { "foreign.funder" => "self.organisation_id" },
  {},
);

=head2 sequencing_runs

Type: has_many

Related object: L<SmallRNA::DB::SequencingRun>

=cut

__PACKAGE__->has_many(
  "sequencing_runs",
  "SmallRNA::DB::SequencingRun",
  { "foreign.sequencing_centre" => "self.organisation_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07002 @ 2011-07-05 17:01:02
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:+G1Q/wXLLwY+EWK0+dd1MA


# You can replace this text with custom content, and it will be preserved on regeneration
1;
