package SmallRNA::DB::Person;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Person

=cut

__PACKAGE__->table("person");

=head1 ACCESSORS

=head2 person_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'person_person_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 first_name

  data_type: 'text'
  is_nullable: 0

=head2 last_name

  data_type: 'text'
  is_nullable: 0

=head2 username

  data_type: 'text'
  is_nullable: 0

=head2 password

  data_type: 'text'
  is_nullable: 1

=head2 role

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 organisation

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=cut

__PACKAGE__->add_columns(
  "person_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "person_person_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "first_name",
  { data_type => "text", is_nullable => 0 },
  "last_name",
  { data_type => "text", is_nullable => 0 },
  "username",
  { data_type => "text", is_nullable => 0 },
  "password",
  { data_type => "text", is_nullable => 1 },
  "role",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "organisation",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
);
__PACKAGE__->set_primary_key("person_id");
__PACKAGE__->add_unique_constraint("person_username_key", ["username"]);
__PACKAGE__->add_unique_constraint("person_full_name_constraint", ["first_name", "last_name"]);

=head1 RELATIONS

=head2 biosamples

Type: has_many

Related object: L<SmallRNA::DB::Biosample>

=cut

__PACKAGE__->has_many(
  "biosamples",
  "SmallRNA::DB::Biosample",
  { "foreign.biosample_creator" => "self.person_id" },
  {},
);

=head2 role

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to("role", "SmallRNA::DB::Cvterm", { cvterm_id => "role" });

=head2 organisation

Type: belongs_to

Related object: L<SmallRNA::DB::Organisation>

=cut

__PACKAGE__->belongs_to(
  "organisation",
  "SmallRNA::DB::Organisation",
  { organisation_id => "organisation" },
);

=head2 pipeprojects

Type: has_many

Related object: L<SmallRNA::DB::Pipeproject>

=cut

__PACKAGE__->has_many(
  "pipeprojects",
  "SmallRNA::DB::Pipeproject",
  { "foreign.owner" => "self.person_id" },
  {},
);

=head2 sequencing_samples

Type: has_many

Related object: L<SmallRNA::DB::SequencingSample>

=cut

__PACKAGE__->has_many(
  "sequencing_samples",
  "SmallRNA::DB::SequencingSample",
  { "foreign.sample_creator" => "self.person_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07002 @ 2011-07-05 17:01:02
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:SZ9B5XTpC3GXgjg1iuu5jw

sub full_name {
  my $self = shift;

  return $self->first_name() . ' ' . $self->last_name();
}

1;
