package SmallRNA::DB::Pipedata;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::Pipedata

=cut

__PACKAGE__->table("pipedata");

=head1 ACCESSORS

=head2 pipedata_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'pipedata_pipedata_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 format_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 content_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 file_name

  data_type: 'text'
  is_nullable: 0

=head2 file_length

  data_type: 'bigint'
  is_nullable: 0

=head2 generating_pipeprocess

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=cut

__PACKAGE__->add_columns(
  "pipedata_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "pipedata_pipedata_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "format_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "content_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "file_name",
  { data_type => "text", is_nullable => 0 },
  "file_length",
  { data_type => "bigint", is_nullable => 0 },
  "generating_pipeprocess",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
);
__PACKAGE__->set_primary_key("pipedata_id");
__PACKAGE__->add_unique_constraint("pipedata_file_name_key", ["file_name"]);

=head1 RELATIONS

=head2 biosample_pipedatas

Type: has_many

Related object: L<SmallRNA::DB::BiosamplePipedata>

=cut

__PACKAGE__->has_many(
  "biosample_pipedatas",
  "SmallRNA::DB::BiosamplePipedata",
  { "foreign.pipedata" => "self.pipedata_id" },
  {},
);

=head2 generating_pipeprocess

Type: belongs_to

Related object: L<SmallRNA::DB::Pipeprocess>

=cut

__PACKAGE__->belongs_to(
  "generating_pipeprocess",
  "SmallRNA::DB::Pipeprocess",
  { pipeprocess_id => "generating_pipeprocess" },
);

=head2 content_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "content_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "content_type" },
);

=head2 format_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "format_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "format_type" },
);

=head2 pipedata_properties

Type: has_many

Related object: L<SmallRNA::DB::PipedataProperty>

=cut

__PACKAGE__->has_many(
  "pipedata_properties",
  "SmallRNA::DB::PipedataProperty",
  { "foreign.pipedata" => "self.pipedata_id" },
  {},
);

=head2 pipeprocess_in_pipedatas

Type: has_many

Related object: L<SmallRNA::DB::PipeprocessInPipedata>

=cut

__PACKAGE__->has_many(
  "pipeprocess_in_pipedatas",
  "SmallRNA::DB::PipeprocessInPipedata",
  { "foreign.pipedata" => "self.pipedata_id" },
  {},
);

=head2 sequencing_runs

Type: has_many

Related object: L<SmallRNA::DB::SequencingRun>

=cut

__PACKAGE__->has_many(
  "sequencing_runs",
  "SmallRNA::DB::SequencingRun",
  { "foreign.initial_pipedata" => "self.pipedata_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07000 @ 2011-06-01 01:11:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:XPKJ1jpk0NrXJpu8dhM2ZQ

__PACKAGE__->many_to_many(next_pipeprocesses => 'pipeprocess_in_pipedatas',
                          'pipeprocess');

__PACKAGE__->many_to_many('biosamples' => 'biosample_pipedatas', 'biosample');

1;
