package SmallRNA::DB::ProcessConf;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::ProcessConf

=cut

__PACKAGE__->table("process_conf");

=head1 ACCESSORS

=head2 process_conf_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'process_conf_process_conf_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 runable_name

  data_type: 'text'
  is_nullable: 1

=head2 detail

  data_type: 'text'
  is_nullable: 1

=head2 type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=cut

__PACKAGE__->add_columns(
  "process_conf_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "process_conf_process_conf_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "runable_name",
  { data_type => "text", is_nullable => 1 },
  "detail",
  { data_type => "text", is_nullable => 1 },
  "type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
);
__PACKAGE__->set_primary_key("process_conf_id");

=head1 RELATIONS

=head2 pipeprocesses

Type: has_many

Related object: L<SmallRNA::DB::Pipeprocess>

=cut

__PACKAGE__->has_many(
  "pipeprocesses",
  "SmallRNA::DB::Pipeprocess",
  { "foreign.process_conf" => "self.process_conf_id" },
  {},
);

=head2 type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to("type", "SmallRNA::DB::Cvterm", { cvterm_id => "type" });

=head2 process_conf_inputs

Type: has_many

Related object: L<SmallRNA::DB::ProcessConfInput>

=cut

__PACKAGE__->has_many(
  "process_conf_inputs",
  "SmallRNA::DB::ProcessConfInput",
  { "foreign.process_conf" => "self.process_conf_id" },
  {},
);


# Created by DBIx::Class::Schema::Loader v0.07000 @ 2011-06-01 01:11:37
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:/MBeWhmJPGaNaPN+lJMFew

sub long_description
{
  my $self = shift;

  my $ret = $self->type()->name();
  my $detail = $self->detail();

  if (defined $detail && length $detail > 0) {
    $ret .= ", $detail";
  }

  my @inputs = $self->process_conf_inputs();

  if (@inputs) {
    $ret .= ', input' . (@inputs == 1 ? '' : 's') . ': [';

    $ret .= join '], [', map {
      my $description = '';
      if (defined $_->content_type()) {
        $description .= $_->content_type()->name();
      }
      if (defined $_->format_type()) {
        if (length $description > 0) {
          $description .= ', ';
        }
        $description .= $_->format_type()->name()
      }
      if (defined $_->ecotype()) {
        if (length $description > 0) {
          $description .= ', ';
        }
        $description .= $_->ecotype()->long_description();
      }
      if (defined $_->biosample_type()) {
        if (length $description > 0) {
          $description .= ', ';
        }
        $description .= $_->biosample_type()->name();
      }
      $description;
    } @inputs;

    $ret .= ']';
  }

  return $ret;
}

# You can replace this text with custom content, and it will be preserved on regeneration
1;
