package SmallRNA::DB::ProcessConfInput;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::ProcessConfInput

=cut

__PACKAGE__->table("process_conf_input");

=head1 ACCESSORS

=head2 process_conf_input_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'process_conf_input_process_conf_input_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 process_conf

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 format_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 content_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 ecotype

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 biosample_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=cut

__PACKAGE__->add_columns(
  "process_conf_input_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "process_conf_input_process_conf_input_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "process_conf",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "format_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "content_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "ecotype",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "biosample_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
);
__PACKAGE__->set_primary_key("process_conf_input_id");

=head1 RELATIONS

=head2 format_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "format_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "format_type" },
);

=head2 biosample_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "biosample_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "biosample_type" },
);

=head2 content_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "content_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "content_type" },
);

=head2 process_conf

Type: belongs_to

Related object: L<SmallRNA::DB::ProcessConf>

=cut

__PACKAGE__->belongs_to(
  "process_conf",
  "SmallRNA::DB::ProcessConf",
  { process_conf_id => "process_conf" },
);

=head2 ecotype

Type: belongs_to

Related object: L<SmallRNA::DB::Ecotype>

=cut

__PACKAGE__->belongs_to(
  "ecotype",
  "SmallRNA::DB::Ecotype",
  { ecotype_id => "ecotype" },
);


# Created by DBIx::Class::Schema::Loader v0.07000 @ 2011-06-01 01:11:38
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:R1A6iropOcbpqa+Vj0t0yA

sub description
{
  my $self = shift;

  my $description = 'Input configuration for: ' . $self->process_conf->type()->name();

  if (defined $self->format_type()) {
    $description .= ', format type: ' . $self->format_type()->name()
  }

  if (defined $self->content_type()) {
    $description .= ', content type: ' . $self->content_type()->name();
  }
}

# You can replace this text with custom content, and it will be preserved on regeneration
1;
