package SmallRNA::DB::SequencingSample;

# Created by DBIx::Class::Schema::Loader
# DO NOT MODIFY THE FIRST PART OF THIS FILE

use strict;
use warnings;

use base 'DBIx::Class::Core';


=head1 NAME

SmallRNA::DB::SequencingSample

=cut

__PACKAGE__->table("sequencing_sample");

=head1 ACCESSORS

=head2 sequencing_sample_id

  data_type: 'integer'
  is_auto_increment: 1
  is_nullable: 0
  sequence: 'sequencing_sample_sequencing_sample_id_seq'

=head2 created_stamp

  data_type: 'timestamp'
  default_value: current_timestamp
  is_nullable: 0
  original: {default_value => \"now()"}

=head2 identifier

  data_type: 'text'
  is_nullable: 0

=head2 sequencing_centre_identifier

  data_type: 'text'
  is_nullable: 1

=head2 sample_creator

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 0

=head2 read_length

  data_type: 'integer'
  is_nullable: 1

=head2 end_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=head2 number_of_lanes

  data_type: 'integer'
  is_nullable: 1

=head2 device_type

  data_type: 'integer'
  is_foreign_key: 1
  is_nullable: 1

=cut

__PACKAGE__->add_columns(
  "sequencing_sample_id",
  {
    data_type         => "integer",
    is_auto_increment => 1,
    is_nullable       => 0,
    sequence          => "sequencing_sample_sequencing_sample_id_seq",
  },
  "created_stamp",
  {
    data_type     => "timestamp",
    default_value => \"current_timestamp",
    is_nullable   => 0,
    original      => { default_value => \"now()" },
  },
  "identifier",
  { data_type => "text", is_nullable => 0 },
  "sequencing_centre_identifier",
  { data_type => "text", is_nullable => 1 },
  "sample_creator",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 },
  "read_length",
  { data_type => "integer", is_nullable => 1 },
  "end_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
  "number_of_lanes",
  { data_type => "integer", is_nullable => 1 },
  "device_type",
  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
);
__PACKAGE__->set_primary_key("sequencing_sample_id");
__PACKAGE__->add_unique_constraint("sequencing_sample_identifier_key", ["identifier"]);

=head1 RELATIONS

=head2 libraries

Type: has_many

Related object: L<SmallRNA::DB::Library>

=cut

__PACKAGE__->has_many(
  "libraries",
  "SmallRNA::DB::Library",
  { "foreign.sequencing_sample" => "self.sequencing_sample_id" },
  {},
);

=head2 sequencing_runs

Type: has_many

Related object: L<SmallRNA::DB::SequencingRun>

=cut

__PACKAGE__->has_many(
  "sequencing_runs",
  "SmallRNA::DB::SequencingRun",
  { "foreign.sequencing_sample" => "self.sequencing_sample_id" },
  {},
);

=head2 end_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "end_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "end_type" },
);

=head2 device_type

Type: belongs_to

Related object: L<SmallRNA::DB::Cvterm>

=cut

__PACKAGE__->belongs_to(
  "device_type",
  "SmallRNA::DB::Cvterm",
  { cvterm_id => "device_type" },
);

=head2 sample_creator

Type: belongs_to

Related object: L<SmallRNA::DB::Person>

=cut

__PACKAGE__->belongs_to(
  "sample_creator",
  "SmallRNA::DB::Person",
  { person_id => "sample_creator" },
);


# Created by DBIx::Class::Schema::Loader v0.07002 @ 2011-07-02 23:35:18
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:ppPN43PquIPlDHR4Ihm7JA

=head2 display_name

 Usage   : my $is_multiplexed = $seq_samp->is_multiplexed()
 Function: return true if and only if this sample is a multiplex of more than
           one library

=cut
sub is_multiplexed {
  my $self = shift;

  my @libraries = $self->libraries();

  if (@libraries > 1) {
    return 1;
  }
}

=head2 display_name

 Usage   : my $has_barcoded_libraries = $seq_samp->has_barcoded_libraries()
 Function: return true if and only if this sample contains one or more libraries
           that have been barcoded

=cut
sub has_barcoded_libraries {
  my $self = shift;

  my @libraries = $self->libraries();

  for my $library (@libraries) {
    if (defined $library->barcode()) {
      return 1;
    }
  }

  return 0;
}


# You can replace this text with custom content, and it will be preserved on regeneration
1;
