#!/usr/bin/perl -w

use strict;
use warnings;
use Carp;

use SmallRNA::DB;
use SmallRNA::DBLayer::Loader;
use SmallRNA::Config;

use Digest::MD5;
use IO::Uncompress::Gunzip qw(gunzip $GunzipError);

use constant {STARTED => 'STARTED', COMPLETE => 'COMPLETE'};
use constant {TRUE => 1, FALSE => 0};

#TODO - check cmd line arguments
my $config_file_name = shift ;
my $seqrunID = shift ;
my $sequence_file_name = shift ;

print "Config:$config_file_name\n" ;
print "Adding:$sequence_file_name to $seqrunID\n" ;

my $config = SmallRNA::Config->new($config_file_name);
my $schema = SmallRNA::DB->new($config);

my $pipeline_data_dir = $config->data_directory() ;

my $loader = SmallRNA::DBLayer::Loader->new(schema => $schema);

# my @new_file_names = (  ) ; TO DO ADD capacity for multiple file names

# Verify the SequencingRun specified doesn't have an initial_pipedata
eval 
{
	print "querying database...\n";
	my $run_rs = $schema->resultset('SequencingRun')->
			search( { sequencing_run_id => $seqrunID },
				{ prefetch => 'sequencing_sample' } ) ;
				

	while( my $run = $run_rs->next() ) 
	{
	    #Check for the sequencing run
		if( defined($run ->initial_pipedata()) )
		{
			print "Data file already present in DB for Sequencing Run $seqrunID\nTo proceed ....\n" ;
			next ;
		}
		
		print "Data file being added for Sequencing Run $seqrunID\n" ;
		my $sequencing_sample = $run->sequencing_sample() ;
		my $sequencing_sample_id = $sequencing_sample->sequencing_sample_id() ;
		print "Sequencing Sample found in DB with ID: $sequencing_sample_id\n" ;

		my @biosamples = map { $_->biosample() } $sequencing_sample->libraries();
		my $molecule_type = $biosamples[0]->molecule_type()->name();
		print "Molecule type: $molecule_type\n" ;		
		$loader->create_initial_pipedata($config, $run, $sequence_file_name, $molecule_type, [@biosamples]);
		print "Added $sequence_file_name to the database\n";
	}
	
	print "Completed\n";
} ;


if( $@ ) 
{
    warn "error during eval(): $@\n";
}

exit ;





